@@ -9,6 +9,13 @@ from timeit import default_timer as timer
 
 from bakplane.extensions.base import ExecutionStatistics
 
+import farmhash
+import ctypes
+
+
+def hash_string(s: str) -> int:
+    return ctypes.c_long(farmhash.fingerprint64(s)).value
+
 
 def to_timestamp(dt: datetime) -> int:
     ts = Timestamp()
